#!/bin/sh

# default configuration - use .config to change!
SVN_BITBAKE_PARENT="svn://svn.berlios.de/bitbake/"
MT_OPENEMBEDDED_BASE="http://sources.dreamboxupdate.com/download/opendreambox/openembedded.db"
MT_OPENEMBEDDED_HOST="monotone.vanille.de"
MT_OPENEMBEDDED_BRANCHES="org.openembedded.dreambox"
MT_OPENEMBEDDED_BRANCH="org.openembedded.dreambox"
MT_DATABASE="openembedded.db"
OE_BASEDIR="$(pwd)"
OE_CACHEDIR="$(pwd)/cache"
OE_SOURCEDIR="$(pwd)/sources"
OE_BUILDDIR="$OE_BASEDIR/build"

MACHINE="dm7025"
DISTRO="opendreambox-1.4"

MT=monotone
SVN=svn

[ -f .config ] && . .config;

cat << eof

This will setup an openembedded environment for you.
You can override certain variables in a .config.

Everything is preconfigured to target a Dreambox DM7025.

I am now checking for some required stuff...
eof

echo -ne "\nChecking for Monotone binary... "
which $MT || {
	echo -e "\nYou need to install monotone.".
	exit 0;
}

monotone --version | grep -q "monotone 0.2" || {
	echo -e "\nYou need monotone 0.2x. pre-0.20 had different netsync protocol."
	exit 0;
}

echo -ne "\nChecking for SVN binary.. "
which $SVN || {
	echo -e "\nYou need to install SVN (subversion), probably trough"
	echo "your distribution-specific package manager."
	exit 0;
}

cat << eof
Fine.

The following configuration will be used:
Repository source paths:
Where to get BitBake from: "$SVN_BITBAKE_PARENT" (SVN_BITBAKE_PARENT)
Where to get packages from: "$MT_OPENEMBEDDED_HOST ($MT_OPENEMBEDDED_BRANCHES)" (BK_OPEBENBEDDED_PARENT, MT_OPENEMBEDDED_BRANCHES)

Local destinations:
Basedir: "$OE_BASEDIR" (OE_BASEDIR)

Cachedir: "$OE_CACHEDIR" (OE_CACHEDIR) (*)
Sources: "$OE_SOURCEDIR" (OE_SOURCEDIR) (*)

Target settings:
Machine: "$MACHINE" (MACHINE)
Distribution: "$DISTRO" (DISTRO)

(*) can and should be shared between installation (even across multiple
targets).

Please check if this is valid, and press enter (or Ctrl+C to abort!)
eof

read ok

echo "Creating directories ($OE_BUILDDIR/conf, $OE_CACHEDIR, $OE_SOURCEDIR)..."
mkdir -p $OE_BUILDDIR/conf $OE_CACHEDIR $OE_SOURCEDIR || {
	echo "Failed to create directories.";
	exit 0;
}

echo "OK, i will now download bitbake and package metadata (openembedded)"
echo "This may take a while."

echo "$SVN checkout $SVN_BITBAKE_PARENT/branches/bitbake-1.6 bb"
[ -e ./bb ] || $SVN checkout $SVN_BITBAKE_PARENT/branches/bitbake-1.6 bb || 
{
	echo "Checking out BitBake from $SVN_BITBAKE_PARENT failed. Please fix."
	exit 0;
}

# try downloading the initial database, otherwise initialize it.
[ -e ./$MT_DATABASE ] || wget $MT_OPENEMBEDDED_BASE -O $MT_DATABASE && $MT --db=$MT_DATABASE db migrate ||
$MT --db=$MT_DATABASE db init || { echo "Initializing monotone database failed."; exit 0; }
$MT --db=$MT_DATABASE pull $MT_OPENEMBEDDED_HOST "$MT_OPENEMBEDDED_BRANCHES"
rm -rf openembedded && $MT --db=$MT_DATABASE co --branch=$MT_OPENEMBEDDED_BRANCH openembedded

echo "Creating configuration..."

cat > $OE_BUILDDIR/conf/local.conf << eof

DL_DIR = "$OE_SOURCEDIR"
OE_BASE = "$OE_BASEDIR"
BBFILES = "\${OE_BASE}/openembedded/packages/*/*.bb"
BBMASK = "(nslu.*|.*-sdk.*)"

PREFERRED_PROVIDERS += " virtual/\${TARGET_PREFIX}gcc-initial:gcc-cross-initial"
PREFERRED_PROVIDERS += " virtual/\${TARGET_PREFIX}gcc:gcc-cross"
PREFERRED_PROVIDERS += " virtual/\${TARGET_PREFIX}g++:gcc-cross"

MACHINE = "$MACHINE"

TARGET_OS = "linux"

DISTRO = "$DISTRO"

CACHE = "$OE_CACHEDIR/oe-cache.\${USER}"

CVS_TARBALL_STASH = "http://www.treke.net/oe/source/"
SOURCEFORGE_MIRROR = "http://puzzle.dl.sourceforge.net/sourceforge"

eof

cat > $OE_BUILDDIR/env.source << eof

OE_BASE=${OE_BASEDIR}
export BBPATH="\${OE_BASE}/openembedded/:\${OE_BASE}/bb/:\${OE_BASE}/build/"
PATH=\$PATH:\${OE_BASE}/bb/bin:$OE_BUILDDIR/tmp/cross/bin
export PATH
export LD_LIBRARY_PATH=
export LANG=C

eof

